@@ -10,13 +10,14 @@ Catalyst::View::Download
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->config(
+	'stash_key' => 'download',
 	'default' => 'text/plain',
 	'content_type' => {
 		'text/csv' => {
@@ -44,7 +45,7 @@ sub render {
 	my ($c, $template, $args) = @_;
 	my $content;
 	
-	my $content_type = $c->response->header('Content-Type') || $self->config->{'default'};
+	my $content_type = $args->{$self->config->{'stash_key'}} || $c->response->header('Content-Type') || $self->config->{'default'};
 	my $options = $self->config->{'content_type'}{$content_type} || return $c->response->body;
 	
 	my $module = $options->{'module'} || return $c->response->body;
@@ -80,6 +81,7 @@ __END__
 		my $content_type = $c->request->params->{'content_type'} || 'plain'; # 'plain' or 'csv'
 
 		$c->header('Content-Type' => 'text/'.$content_type); # Set the content type so Catalyst::View::Download can determine how to process it.
+    $c->stash->{'download'} = 'text/'.$content_type; # Or set the content type in the stash variable 'download' (note this is configurable) to process it.
 
 		# Array reference of array references.
 		my $data = [
@@ -90,7 +92,9 @@ __END__
 		];
 
 		# If the chosen content_type is 'csv' then the render function of Catalyst::View::Download::CSV will be called which uses the 'csv' stash key
-		$c->stash->{'csv'} = $data;
+		$c->stash->{'csv'} = {
+      data => $data
+    };
 
 		# For plain text in this example we just dump the example array
 		# Catalyst::View::Download::Plain will use either the 'plain' stash key or just pull from $c->response->body
@@ -100,6 +104,10 @@ __END__
 		# Finally forward processing to the Download View
 		$c->forward('MyApp::View::Download');
 	}
+
+=head1 DESCRIPTION
+
+A view module to help in the convenience of downloading data into many supportable formats.
 	
 =head1 SUBROUTINES
 
@@ -115,6 +123,12 @@ Allows others to use this view for much more fine-grained content generation.
 
 =over 4
 
+=item stash_key
+
+Determines the key in the stash this view will look for when attempting to retrieve the type of format to process. If this key isn't found it will search for a Content-Type header for the format. Further if neither are found a default format will be applied.
+
+	$c->view('MyApp::View::Download')->config->{'stash_key'} = 'content_type';
+
 =item default
 
 Determines which Content-Type to use by default. Default: 'text/plain'
@@ -188,49 +202,15 @@ Catalyst::View::Download has the following default configuration for this Conten
 	
 See L<Catalyst::View::Download::Plain> for more details.
 
-=head1 AUTHOR
-
-Travis Chase, C<< <gaudeon at cpan.org> >>
-
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-catalyst-view-download at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Catalyst-View-Download>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Catalyst::View::Download
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Catalyst-View-Download>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Catalyst-View-Download>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Catalyst-View-Download>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Catalyst-View-Download>
-
-=back
-
 =head1 SEE ALSO
 
 L<Catalyst> L<Catalyst::View>
 
-=head1 CONTRIBUTORS
+=head1 AUTHOR
+
+Travis Chase, C<< <gaudeon at cpan.org> >>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -242,13 +222,15 @@ Thanks to following people for their constructive comments and help:
 
 =item Jonathan Rockway
 
+=item Jon Schutz
+
 =back
 
 Thanks also to my company Ti4 Technologies for their financial support. L<http://www.ti4tech.com/>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Travis Chase, all rights reserved.
+Copyright 2008 Travis Chase.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
