@@ -5,6 +5,7 @@ use warnings;
 use base qw( Catalyst::View );
 
 use Catalyst::Exception;
+use Params::Validate;
 use Text::CSV;
 
 =head1 NAME
@@ -42,15 +43,11 @@ sub render {
 	
 	my $stash_key = $self->config->{'stash_key'};
 	
-  if(defined($args->{$stash_key}) && ref($args->{$stash_key}) =~ /ARRAY/) {
-		push(@data, @{$args->{$stash_key}});
+  if(defined($args->{$stash_key}) && ref($args->{$stash_key}) =~ /HASH/ && defined($args->{$stash_key}{data}) && $args->{$stash_key}{data} =~ /ARRAY/) {
+	  push(@data, @{$args->{$stash_key}{data}});
   }
   else {
-    foreach my $key(%{$args}) {
-      if(ref($args->{$key}) =~ /ARRAY/) {
-        push(@data,@{$args->{$key}});
-      }
-    }
+	  return $content;	
   }
 	
 	my $csv = Text::CSV->new ({
@@ -95,8 +92,10 @@ __END__
       ['col 1','col 2','col ...','col N']  # row N
     ];
 
-    # To output your data in comma seperated values just pass your array by reference into the 'csv' key of the stash
-    $c->stash->{'csv'} = $data;
+    # To output your data in comma seperated values pass your array by reference into a hashref as the key 'data' and then into whatever stash key you have defined (default is 'csv'). Content passed via the stash must be passed in a hashref in the key labeled 'data'
+    $c->stash->{'csv'} = {
+			'data' => $data
+		};
 
     # Finally forward processing to the CSV View
     $c->forward('MyApp::View::Download::CSV');
@@ -122,7 +121,9 @@ __END__
                 'col 1 row N'
                );
 
-    $c->stash->{'csv'} = \@data;
+    $c->stash->{'csv'} = {
+			'data' => \@data
+		};
 
     $c->forward('MyApp::View::Download::CSV');
   }
@@ -147,11 +148,17 @@ __END__
 			'eol' => "\n",
 		);
 
-    $c->stash->{'data'} = $data;
+    $c->stash->{'data'} = {
+			'data' => $data
+		};
 		
 		$c->forward('MyApp::View::Download::CSV');
   }
 
+=head1 DESCRIPTION
+
+Takes a nested array and outputs CSV formatted content.
+
 =head1 SUBROUTINES
 
 =head2 process
@@ -168,33 +175,33 @@ Allows others to use this view for much more fine-grained content generation.
 
 =item stash_key
 
-Determines the key in the stash this view will look for when attempting to retrieve data to process. If this key isn't found it will then look at the stash as a whole, find any array references and process them.
+Determines the key in the stash this view will look for when attempting to retrieve data to process. If this key isn't found it will then look at the stash as a whole, find any array references and process them. Data passed into the defined stash_key must be a HASHREF with at least the key 'data' existing with the nested array of data to create a CSV from.
 
-	$c->view('MyApp::View::Download')->config->{'stash_key'} = 'data';
+	$c->view('MyApp::View::Download::CSV')->config->{'stash_key'} = 'data';
 
 =item quote_char
 
 Determines what value will be enclosed within if it contains whitespace or the delimiter character. DEFAULT: '"'
 
-  $c->view('MyApp::View::Download')->config->{'quote_char'} = '/';
+  $c->view('MyApp::View::Download::CSV')->config->{'quote_char'} = '/';
 
 =item escape_char
 
 Determines what value will be to escape any delimiter's found in a column. DEFAULT: '"'
 
-  $c->view('MyApp::View::Download')->config->{'escape_char'} = '/';
+  $c->view('MyApp::View::Download::CSV')->config->{'escape_char'} = '/';
 
 =item sep_char
 
 Determines the separator between columns. DEFAULT: ','
 
-  $c->view('MyApp::View::Download')->config->{'sep_char'} = '|';
+  $c->view('MyApp::View::Download::CSV')->config->{'sep_char'} = '|';
 
 =item eol
 
 Any characters defined in eol will be placed at the end of a row. DEFAULT: '\n'
 
-  $c->view('MyApp::View::Download')->config->{'eol'} = '\0';
+  $c->view('MyApp::View::Download::CSV')->config->{'eol'} = '\0';
 
 =back
 
@@ -206,13 +213,9 @@ Travis Chase, C<< <gaudeon at cpan.org> >>
 
 L<Catalyst> L<Catalyst::View> L<Catalyst::View::Download> L<Text::CSV>
 
-=head1 CONTRIBUTORS
-
-=head1 ACKNOWLEDGEMENTS
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Travis Chase, all rights reserved.
+Copyright 2008 Travis Chase.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
