@@ -33,7 +33,7 @@ sub render {
 	
 	my $stash_key = $self->config->{'stash_key'};
 	
-	$content = $c->stash->{$stash_key} || $c->response->body;
+	$content = $c->stash->{$stash_key}{'data'} || $c->response->body;
 	
   return $content;
 }
@@ -55,7 +55,9 @@ __END__
 		my $content = "Some Text";
   
     # To output your data just pass your content into the 'plain' key of the stash
-    $c->stash->{'plain'} = $content;
+    $c->stash->{'plain'} = {
+			data => $content
+		};
 		
 		# Or into the body of the response for this action
 		$c->response->body($content);
@@ -64,6 +66,10 @@ __END__
     $c->forward('MyApp::View::Download::Plain');
   }
 	
+=head1 DESCRIPTION
+
+Takes content and outputs the content as plain text.
+
 =head1 SUBROUTINES
 
 =head2 process
@@ -80,9 +86,9 @@ Allows others to use this view for much more fine-grained content generation.
 
 =item stash_key
 
-Determines the key in the stash this view will look for when attempting to retrieve content to process. If this key isn't found it will then look at $c->response->body for content.
+Determines the key in the stash this view will look for when attempting to retrieve content to process. If this key isn't found it will then look at $c->response->body for content. Content when passed via the stash must be passed in a hashref in the key labeled 'data'
 
-  $c->view('MyApp::View::Download')->config->{'stash_key'} = 'content';
+  $c->view('MyApp::View::Download::Plain')->config->{'stash_key'} = 'content';
 
 =back
 
@@ -92,15 +98,11 @@ Travis Chase, C<< <gaudeon at cpan.org> >>
 
 =head1 SEE ALSO
 
-L<Catalyst> L<Catalyst::View>
-
-=head1 CONTRIBUTORS
-
-=head1 ACKNOWLEDGEMENTS
+L<Catalyst> L<Catalyst::View> L<Catalyst::View::Download>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Travis Chase, all rights reserved.
+Copyright 2008 Travis Chase.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
